Documentation
¶
Overview ¶
Package servicecatalog contains all of the sources needed to make servicebrokers and their related service objects. +groupName=servicecatalog.k8s.io
Index ¶
- Constants
- Variables
- func DeepCopy_servicecatalog_AlphaPodPresetTemplate(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_Binding(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BindingCondition(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BindingList(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BindingSpec(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BindingStatus(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_Broker(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BrokerAuthInfo(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BrokerCondition(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BrokerList(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BrokerSpec(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_BrokerStatus(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_Instance(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_InstanceCondition(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_InstanceList(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_InstanceSpec(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_InstanceStatus(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_ServiceClass(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_ServiceClassList(in interface{}, out interface{}, c *conversion.Cloner) error
- func DeepCopy_servicecatalog_ServicePlan(in interface{}, out interface{}, c *conversion.Cloner) error
- func Kind(kind string) schema.GroupKind
- func RegisterDeepCopies(scheme *runtime.Scheme) error
- func RegisterDefaults(scheme *runtime.Scheme) error
- func Resource(resource string) schema.GroupResource
- type AlphaPodPresetTemplate
- type Binding
- type BindingCondition
- type BindingConditionType
- type BindingList
- type BindingSpec
- type BindingStatus
- type Broker
- type BrokerAuthInfo
- type BrokerCondition
- type BrokerConditionType
- type BrokerList
- type BrokerSpec
- type BrokerStatus
- type ConditionStatus
- type Instance
- type InstanceCondition
- type InstanceConditionType
- type InstanceList
- type InstanceSpec
- type InstanceStatus
- type ServiceClass
- type ServiceClassList
- type ServicePlan
Constants ¶
const (
FinalizerServiceCatalog string = "kubernetes-incubator/service-catalog"
)
These are internal finalizer values to service catalog, must be qualified name.
const GroupName = "servicecatalog.k8s.io"
GroupName is the group name use in this package
Variables ¶
var ( // SchemeBuilder needs to be exported as `SchemeBuilder` so // the code-generation can find it. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is exposed for API installation AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func DeepCopy_servicecatalog_AlphaPodPresetTemplate ¶
func DeepCopy_servicecatalog_AlphaPodPresetTemplate(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_Binding ¶
func DeepCopy_servicecatalog_Binding(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BindingCondition ¶
func DeepCopy_servicecatalog_BindingCondition(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BindingList ¶
func DeepCopy_servicecatalog_BindingList(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BindingSpec ¶
func DeepCopy_servicecatalog_BindingSpec(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BindingStatus ¶
func DeepCopy_servicecatalog_BindingStatus(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_Broker ¶
func DeepCopy_servicecatalog_Broker(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BrokerAuthInfo ¶
func DeepCopy_servicecatalog_BrokerAuthInfo(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BrokerCondition ¶
func DeepCopy_servicecatalog_BrokerCondition(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BrokerList ¶
func DeepCopy_servicecatalog_BrokerList(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BrokerSpec ¶
func DeepCopy_servicecatalog_BrokerSpec(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_BrokerStatus ¶
func DeepCopy_servicecatalog_BrokerStatus(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_Instance ¶
func DeepCopy_servicecatalog_Instance(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_InstanceCondition ¶
func DeepCopy_servicecatalog_InstanceCondition(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_InstanceList ¶
func DeepCopy_servicecatalog_InstanceList(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_InstanceSpec ¶
func DeepCopy_servicecatalog_InstanceSpec(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_InstanceStatus ¶
func DeepCopy_servicecatalog_InstanceStatus(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_ServiceClass ¶
func DeepCopy_servicecatalog_ServiceClass(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_ServiceClassList ¶
func DeepCopy_servicecatalog_ServiceClassList(in interface{}, out interface{}, c *conversion.Cloner) error
func DeepCopy_servicecatalog_ServicePlan ¶
func DeepCopy_servicecatalog_ServicePlan(in interface{}, out interface{}, c *conversion.Cloner) error
func RegisterDeepCopies ¶
RegisterDeepCopies adds deep-copy functions to the given scheme. Public to allow building arbitrary schemes.
func RegisterDefaults ¶
RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type AlphaPodPresetTemplate ¶
type AlphaPodPresetTemplate struct {
// Name is the name of the PodPreset to create.
Name string
// Selector is the LabelSelector of the PodPreset to create.
Selector metav1.LabelSelector
}
AlphaPodPresetTemplate represents how a PodPreset should be created for a Binding.
type Binding ¶
type Binding struct {
metav1.TypeMeta
metav1.ObjectMeta
Spec BindingSpec
Status BindingStatus
}
Binding represents a "used by" relationship between an application and an Instance.
type BindingCondition ¶
type BindingCondition struct {
// Type of the condition, currently ('Ready').
Type BindingConditionType
// Status of the condition, one of ('True', 'False', 'Unknown').
Status ConditionStatus
// LastTransitionTime is the timestamp corresponding to the last status
// change of this condition.
LastTransitionTime metav1.Time
// Reason is a brief machine readable explanation for the condition's last
// transition.
Reason string
// Message is a human readable description of the details of the last
// transition, complementing reason.
Message string
}
BindingCondition condition information for a Binding.
type BindingConditionType ¶
type BindingConditionType string
BindingConditionType represents a BindingCondition value.
const ( // BindingConditionReady represents a BindingCondition is in ready state. BindingConditionReady BindingConditionType = "Ready" )
type BindingList ¶
BindingList is a list of Bindings.
type BindingSpec ¶
type BindingSpec struct {
// InstanceRef is the reference to the Instance this Binding is to.
//
// Immutable.
InstanceRef v1.LocalObjectReference
// Parameters is a YAML representation of the properties to be
// passed to the underlying broker.
Parameters *runtime.RawExtension
// SecretName is the name of the secret to create in the Binding's
// namespace that will hold the credentials associated with the Binding.
SecretName string
// ExternalID is the identity of this object for use with the OSB API.
//
// Immutable.
ExternalID string
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// AlphaPodPresetTemplate describes how a PodPreset should be created once
// the Binding has been made. If supplied, a PodPreset will be created
// using information in this field once the Binding has been made in the
// Broker. The PodPreset will use the EnvFrom feature to expose the keys
// from the Secret (specified by SecretName) that holds the Binding
// information into Pods.
//
// In the future, we will provide a higher degree of control over the PodPreset.
AlphaPodPresetTemplate *AlphaPodPresetTemplate
}
BindingSpec represents the desired state of a Binding.
type BindingStatus ¶
type BindingStatus struct {
Conditions []BindingCondition
// Checksum is the checksum of the BindingSpec that was last successfully
// reconciled against the broker.
Checksum *string
}
BindingStatus represents the current status of a Binding.
type Broker ¶
type Broker struct {
metav1.TypeMeta
metav1.ObjectMeta
Spec BrokerSpec
Status BrokerStatus
}
Broker represents an entity that provides ServiceClasses for use in the service catalog.
type BrokerAuthInfo ¶
type BrokerAuthInfo struct {
// BasicAuthSecret is a reference to a Secret containing auth information the
// catalog should use to authenticate to this Broker using basic auth.
BasicAuthSecret *v1.ObjectReference
}
BrokerAuthInfo is a union type that contains information on one of the authentication methods the the service catalog and brokers may support, according to the OpenServiceBroker API specification (https://github.com/openservicebrokerapi/servicebroker/blob/master/spec.md).
Note that we currently restrict a single broker to have only one of these fields set on it.
type BrokerCondition ¶
type BrokerCondition struct {
// Type of the condition, currently ('Ready').
Type BrokerConditionType
// Status of the condition, one of ('True', 'False', 'Unknown').
Status ConditionStatus
// LastTransitionTime is the timestamp corresponding to the last status
// change of this condition.
LastTransitionTime metav1.Time
// Reason is a brief machine readable explanation for the condition's last
// transition.
Reason string
// Message is a human readable description of the details of the last
// transition, complementing reason.
Message string
}
BrokerCondition contains condition information for a Broker.
type BrokerConditionType ¶
type BrokerConditionType string
BrokerConditionType represents a broker condition value.
const ( // BrokerConditionReady represents the fact that a given broker condition // is in ready state. BrokerConditionReady BrokerConditionType = "Ready" )
type BrokerList ¶
BrokerList is a list of Brokers.
type BrokerSpec ¶
type BrokerSpec struct {
// URL is the address used to communicate with the Broker.
URL string
// AuthInfo contains the data that the service catalog should use to authenticate
// with the Broker.
AuthInfo *BrokerAuthInfo
}
BrokerSpec represents a description of a Broker.
type BrokerStatus ¶
type BrokerStatus struct {
Conditions []BrokerCondition
}
BrokerStatus represents the current status of a Broker.
type ConditionStatus ¶
type ConditionStatus string
ConditionStatus represents a condition's status.
const ( // ConditionTrue represents the fact that a given condition is true ConditionTrue ConditionStatus = "True" // ConditionFalse represents the fact that a given condition is false ConditionFalse ConditionStatus = "False" // ConditionUnknown represents the fact that a given condition is unknown ConditionUnknown ConditionStatus = "Unknown" )
These are valid condition statuses. "ConditionTrue" means a resource is in the condition; "ConditionFalse" means a resource is not in the condition; "ConditionUnknown" means kubernetes can't decide if a resource is in the condition or not. In the future, we could add other intermediate conditions, e.g. ConditionDegraded.
type Instance ¶
type Instance struct {
metav1.TypeMeta
metav1.ObjectMeta
Spec InstanceSpec
Status InstanceStatus
}
Instance represents a provisioned instance of a ServiceClass.
type InstanceCondition ¶
type InstanceCondition struct {
// Type of the condition, currently ('Ready').
Type InstanceConditionType
// Status of the condition, one of ('True', 'False', 'Unknown').
Status ConditionStatus
// LastTransitionTime is the timestamp corresponding to the last status
// change of this condition.
LastTransitionTime metav1.Time
// Reason is a brief machine readable explanation for the condition's last
// transition.
Reason string
// Message is a human readable description of the details of the last
// transition, complementing reason.
Message string
}
InstanceCondition contains condition information about an Instance.
type InstanceConditionType ¶
type InstanceConditionType string
InstanceConditionType represents a instance condition value.
const ( // InstanceConditionReady represents that a given InstanceCondition is in // ready state. InstanceConditionReady InstanceConditionType = "Ready" )
type InstanceList ¶
InstanceList is a list of instances.
type InstanceSpec ¶
type InstanceSpec struct {
// ServiceClassName is the name of the ServiceClass this Instance
// should be provisioned from.
//
// Immutable.
ServiceClassName string
// PlanName is the name of the ServicePlan this Instance should be
// provisioned from.
PlanName string
// Parameters is a YAML representation of the properties to be
// passed to the underlying broker.
Parameters *runtime.RawExtension
// ExternalID is the identity of this object for use with the OSB API.
//
// Immutable.
ExternalID string
}
InstanceSpec represents the desired state of an Instance.
type InstanceStatus ¶
type InstanceStatus struct {
// Conditions is an array of InstanceConditions capturing aspects of an
// Instance's status.
Conditions []InstanceCondition
// AsyncOpInProgress is set to true if there is an ongoing async operation
// against this Instance in progress.
AsyncOpInProgress bool
// LastOperation is the string that the broker may have returned when
// an async operation started, it should be sent back to the broker
// on poll requests as a query param.
LastOperation *string
// DashboardURL is the URL of a web-based management user interface for
// the service instance.
DashboardURL *string
// Checksum is the checksum of the InstanceSpec that was last successfully
// reconciled against the broker.
Checksum *string
}
InstanceStatus represents the current status of an Instance.
type ServiceClass ¶
type ServiceClass struct {
metav1.TypeMeta
metav1.ObjectMeta
// BrokerName is the reference to the Broker that provides this
// ServiceClass.
//
// Immutable.
BrokerName string
// Description is a short description of this ServiceClass.
Description string
// Bindable indicates whether a user can create bindings to an Instance
// provisioned from this service. ServicePlan has an optional field called
// Bindable which overrides the value of this field.
Bindable bool
// Plans is the list of ServicePlans for this ServiceClass. All
// ServiceClasses have at least one ServicePlan.
Plans []ServicePlan
// PlanUpdatable indicates whether instances provisioned from this
// ServiceClass may change ServicePlans after being provisioned.
PlanUpdatable bool
// ExternalID is the identity of this object for use with the OSB API.
//
// Immutable.
ExternalID string
// ExternalMetadata is a blob of information about the ServiceClass, meant
// to be user-facing content and display instructions. This field may
// contain platform-specific conventional values.
ExternalMetadata *runtime.RawExtension
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// Tags is a list of strings that represent different classification
// attributes of the ServiceClass. These are used in Cloud Foundry in a
// way similar to Kubernetes labels, but they currently have no special
// meaning in Kubernetes.
AlphaTags []string
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// AlphaRequires exposes a list of Cloud Foundry-specific 'permissions'
// that must be granted to an instance of this service within Cloud
// Foundry. These 'permissions' have no meaning within Kubernetes and an
// Instance provisioned from this ServiceClass will not work correctly.
AlphaRequires []string
}
ServiceClass represents an offering in the service catalog.
type ServiceClassList ¶
type ServiceClassList struct {
metav1.TypeMeta
metav1.ListMeta
Items []ServiceClass
}
ServiceClassList is a list of ServiceClasses.
type ServicePlan ¶
type ServicePlan struct {
// Name is the CLI-friendly name of this ServicePlan.
Name string
// ExternalID is the identity of this object for use with the OSB API.
//
// Immutable.
ExternalID string
// Description is a short description of this ServicePlan.
Description string
// Bindable indicates whether a user can create bindings to an Instance
// using this ServicePlan. If set, overrides the value of the
// ServiceClass.Bindable field.
Bindable *bool
// Free indicates whether this ServicePlan is available at no cost.
Free bool
// ExternalMetadata is a blob of information about the plan, meant to be
// user-facing content and display instructions. This field may contain
// platform-specific conventional values.
ExternalMetadata *runtime.RawExtension
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// AlphaInstanceCreateParameterSchema is the schema for the parameters
// that may be supplied when provisioning a new Instance on this plan.
AlphaInstanceCreateParameterSchema *runtime.RawExtension
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// AlphaInstanceUpdateParameterSchema is the schema for the parameters
// that may be updated once an Instance has been provisioned on this plan.
// This field only has meaning if the ServiceClass is PlanUpdatable.
AlphaInstanceUpdateParameterSchema *runtime.RawExtension
// Currently, this field is ALPHA: it may change or disappear at any time
// and its data will not be migrated.
//
// AlphaBindingCreateParameterSchema is the schema for the parameters that
// may be supplied binding to an Instance on this plan.
AlphaBindingCreateParameterSchema *runtime.RawExtension
}
ServicePlan represents a tier of a ServiceClass.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
checksum
|
|
|
Package install registers the service-catalog API group
|
Package install registers the service-catalog API group |
|
Package testapi provides a helper for retrieving the KUBE_TEST_API environment variable.
|
Package testapi provides a helper for retrieving the KUBE_TEST_API environment variable. |
|
Package v1alpha1 defines all of the versioned (v1alpha1) definitions of the service catalog model.
|
Package v1alpha1 defines all of the versioned (v1alpha1) definitions of the service catalog model. |