Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterServiceBrokerExpansion
- type ClusterServiceBrokerInterface
- type ClusterServiceBrokersGetter
- type ClusterServiceClassExpansion
- type ClusterServiceClassInterface
- type ClusterServiceClassesGetter
- type ClusterServicePlanExpansion
- type ClusterServicePlanInterface
- type ClusterServicePlansGetter
- type ServiceBindingExpansion
- type ServiceBindingInterface
- type ServiceBindingsGetter
- type ServiceInstanceExpansion
- type ServiceInstanceInterface
- type ServiceInstancesGetter
- type ServicecatalogClient
- func (c *ServicecatalogClient) ClusterServiceBrokers() ClusterServiceBrokerInterface
- func (c *ServicecatalogClient) ClusterServiceClasses() ClusterServiceClassInterface
- func (c *ServicecatalogClient) ClusterServicePlans() ClusterServicePlanInterface
- func (c *ServicecatalogClient) RESTClient() rest.Interface
- func (c *ServicecatalogClient) ServiceBindings(namespace string) ServiceBindingInterface
- func (c *ServicecatalogClient) ServiceInstances(namespace string) ServiceInstanceInterface
- type ServicecatalogInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterServiceBrokerExpansion ¶
type ClusterServiceBrokerExpansion interface{}
type ClusterServiceBrokerInterface ¶
type ClusterServiceBrokerInterface interface {
Create(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
Update(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
UpdateStatus(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServiceBroker, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServiceBrokerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServiceBroker, err error)
ClusterServiceBrokerExpansion
}
ClusterServiceBrokerInterface has methods to work with ClusterServiceBroker resources.
type ClusterServiceBrokersGetter ¶
type ClusterServiceBrokersGetter interface {
ClusterServiceBrokers() ClusterServiceBrokerInterface
}
ClusterServiceBrokersGetter has a method to return a ClusterServiceBrokerInterface. A group's client should implement this interface.
type ClusterServiceClassExpansion ¶
type ClusterServiceClassExpansion interface{}
type ClusterServiceClassInterface ¶
type ClusterServiceClassInterface interface {
Create(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
Update(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
UpdateStatus(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServiceClass, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServiceClassList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServiceClass, err error)
ClusterServiceClassExpansion
}
ClusterServiceClassInterface has methods to work with ClusterServiceClass resources.
type ClusterServiceClassesGetter ¶
type ClusterServiceClassesGetter interface {
ClusterServiceClasses() ClusterServiceClassInterface
}
ClusterServiceClassesGetter has a method to return a ClusterServiceClassInterface. A group's client should implement this interface.
type ClusterServicePlanExpansion ¶
type ClusterServicePlanExpansion interface{}
type ClusterServicePlanInterface ¶
type ClusterServicePlanInterface interface {
Create(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
Update(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
UpdateStatus(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServicePlan, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServicePlanList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServicePlan, err error)
ClusterServicePlanExpansion
}
ClusterServicePlanInterface has methods to work with ClusterServicePlan resources.
type ClusterServicePlansGetter ¶
type ClusterServicePlansGetter interface {
ClusterServicePlans() ClusterServicePlanInterface
}
ClusterServicePlansGetter has a method to return a ClusterServicePlanInterface. A group's client should implement this interface.
type ServiceBindingExpansion ¶
type ServiceBindingExpansion interface{}
type ServiceBindingInterface ¶
type ServiceBindingInterface interface {
Create(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
Update(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
UpdateStatus(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceBinding, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceBindingList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceBinding, err error)
ServiceBindingExpansion
}
ServiceBindingInterface has methods to work with ServiceBinding resources.
type ServiceBindingsGetter ¶
type ServiceBindingsGetter interface {
ServiceBindings(namespace string) ServiceBindingInterface
}
ServiceBindingsGetter has a method to return a ServiceBindingInterface. A group's client should implement this interface.
type ServiceInstanceExpansion ¶
type ServiceInstanceExpansion interface{}
type ServiceInstanceInterface ¶
type ServiceInstanceInterface interface {
Create(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
Update(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
UpdateStatus(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceInstance, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceInstanceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceInstance, err error)
ServiceInstanceExpansion
}
ServiceInstanceInterface has methods to work with ServiceInstance resources.
type ServiceInstancesGetter ¶
type ServiceInstancesGetter interface {
ServiceInstances(namespace string) ServiceInstanceInterface
}
ServiceInstancesGetter has a method to return a ServiceInstanceInterface. A group's client should implement this interface.
type ServicecatalogClient ¶
type ServicecatalogClient struct {
// contains filtered or unexported fields
}
ServicecatalogClient is used to interact with features provided by the servicecatalog.k8s.io group.
func New ¶
func New(c rest.Interface) *ServicecatalogClient
New creates a new ServicecatalogClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ServicecatalogClient, error)
NewForConfig creates a new ServicecatalogClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ServicecatalogClient
NewForConfigOrDie creates a new ServicecatalogClient for the given config and panics if there is an error in the config.
func (*ServicecatalogClient) ClusterServiceBrokers ¶
func (c *ServicecatalogClient) ClusterServiceBrokers() ClusterServiceBrokerInterface
func (*ServicecatalogClient) ClusterServiceClasses ¶
func (c *ServicecatalogClient) ClusterServiceClasses() ClusterServiceClassInterface
func (*ServicecatalogClient) ClusterServicePlans ¶
func (c *ServicecatalogClient) ClusterServicePlans() ClusterServicePlanInterface
func (*ServicecatalogClient) RESTClient ¶
func (c *ServicecatalogClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ServicecatalogClient) ServiceBindings ¶
func (c *ServicecatalogClient) ServiceBindings(namespace string) ServiceBindingInterface
func (*ServicecatalogClient) ServiceInstances ¶
func (c *ServicecatalogClient) ServiceInstances(namespace string) ServiceInstanceInterface
type ServicecatalogInterface ¶
type ServicecatalogInterface interface {
RESTClient() rest.Interface
ClusterServiceBrokersGetter
ClusterServiceClassesGetter
ClusterServicePlansGetter
ServiceBindingsGetter
ServiceInstancesGetter
}