Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindingInformer ¶
type BindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.BindingLister
}
BindingInformer provides access to a shared informer and lister for Bindings.
type BrokerInformer ¶
type BrokerInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.BrokerLister
}
BrokerInformer provides access to a shared informer and lister for Brokers.
type InstanceInformer ¶
type InstanceInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.InstanceLister
}
InstanceInformer provides access to a shared informer and lister for Instances.
type Interface ¶
type Interface interface {
// Bindings returns a BindingInformer.
Bindings() BindingInformer
// Brokers returns a BrokerInformer.
Brokers() BrokerInformer
// Instances returns a InstanceInformer.
Instances() InstanceInformer
// ServiceClasses returns a ServiceClassInformer.
ServiceClasses() ServiceClassInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory) Interface
New returns a new Interface.
type ServiceClassInformer ¶
type ServiceClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServiceClassLister
}
ServiceClassInformer provides access to a shared informer and lister for ServiceClasses.
Click to show internal directories.
Click to hide internal directories.