Documentation
¶
Index ¶
- type BindingLister
- type BindingListerExpansion
- type BindingNamespaceLister
- type BindingNamespaceListerExpansion
- type BrokerLister
- type BrokerListerExpansion
- type InstanceLister
- type InstanceListerExpansion
- type InstanceNamespaceLister
- type InstanceNamespaceListerExpansion
- type ServiceClassLister
- type ServiceClassListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindingLister ¶
type BindingLister interface {
// List lists all Bindings in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Binding, err error)
// Bindings returns an object that can list and get Bindings.
Bindings(namespace string) BindingNamespaceLister
BindingListerExpansion
}
BindingLister helps list Bindings.
func NewBindingLister ¶
func NewBindingLister(indexer cache.Indexer) BindingLister
NewBindingLister returns a new BindingLister.
type BindingListerExpansion ¶
type BindingListerExpansion interface{}
BindingListerExpansion allows custom methods to be added to BindingLister.
type BindingNamespaceLister ¶
type BindingNamespaceLister interface {
// List lists all Bindings in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Binding, err error)
// Get retrieves the Binding from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Binding, error)
BindingNamespaceListerExpansion
}
BindingNamespaceLister helps list and get Bindings.
type BindingNamespaceListerExpansion ¶
type BindingNamespaceListerExpansion interface{}
BindingNamespaceListerExpansion allows custom methods to be added to BindingNamespaeLister.
type BrokerLister ¶
type BrokerLister interface {
// List lists all Brokers in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Broker, err error)
// Get retrieves the Broker from the index for a given name.
Get(name string) (*v1alpha1.Broker, error)
BrokerListerExpansion
}
BrokerLister helps list Brokers.
func NewBrokerLister ¶
func NewBrokerLister(indexer cache.Indexer) BrokerLister
NewBrokerLister returns a new BrokerLister.
type BrokerListerExpansion ¶
type BrokerListerExpansion interface{}
BrokerListerExpansion allows custom methods to be added to BrokerLister.
type InstanceLister ¶
type InstanceLister interface {
// List lists all Instances in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Instance, err error)
// Instances returns an object that can list and get Instances.
Instances(namespace string) InstanceNamespaceLister
InstanceListerExpansion
}
InstanceLister helps list Instances.
func NewInstanceLister ¶
func NewInstanceLister(indexer cache.Indexer) InstanceLister
NewInstanceLister returns a new InstanceLister.
type InstanceListerExpansion ¶
type InstanceListerExpansion interface{}
InstanceListerExpansion allows custom methods to be added to InstanceLister.
type InstanceNamespaceLister ¶
type InstanceNamespaceLister interface {
// List lists all Instances in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Instance, err error)
// Get retrieves the Instance from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Instance, error)
InstanceNamespaceListerExpansion
}
InstanceNamespaceLister helps list and get Instances.
type InstanceNamespaceListerExpansion ¶
type InstanceNamespaceListerExpansion interface{}
InstanceNamespaceListerExpansion allows custom methods to be added to InstanceNamespaeLister.
type ServiceClassLister ¶
type ServiceClassLister interface {
// List lists all ServiceClasses in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ServiceClass, err error)
// Get retrieves the ServiceClass from the index for a given name.
Get(name string) (*v1alpha1.ServiceClass, error)
ServiceClassListerExpansion
}
ServiceClassLister helps list ServiceClasses.
func NewServiceClassLister ¶
func NewServiceClassLister(indexer cache.Indexer) ServiceClassLister
NewServiceClassLister returns a new ServiceClassLister.
type ServiceClassListerExpansion ¶
type ServiceClassListerExpansion interface{}
ServiceClassListerExpansion allows custom methods to be added to ServiceClassLister.